package ctbrec.ui.sites.bonga;

import ctbrec.Config;
import ctbrec.sites.bonga.BongaCams;
import ctbrec.ui.DesktopIntegration;
import ctbrec.ui.settings.SettingsTab;
import ctbrec.ui.sites.AbstractConfigUI;
import java.util.ArrayList;
import java.util.List;
import javafx.geometry.Insets;
import javafx.scene.Parent;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
import javafx.scene.control.Label;
import javafx.scene.control.PasswordField;
import javafx.scene.control.TextField;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Priority;

public class BongaCamsConfigUI extends AbstractConfigUI {
    private BongaCams bongaCams;

    public BongaCamsConfigUI(BongaCams bongaCams) {
        this.bongaCams = bongaCams;
    }

    @Override
    public Parent createConfigPanel() {
        GridPane layout = SettingsTab.createGridLayout();
        var settings = Config.getInstance().getSettings();

        var row = 0;
        var l = new Label("Active");
        layout.add(l, 0, row);
        var enabled = new CheckBox();
        enabled.setSelected(!settings.disabledSites.contains(bongaCams.getName()));
        enabled.setOnAction(e -> {
            if(enabled.isSelected()) {
                settings.disabledSites.remove(bongaCams.getName());
            } else {
                settings.disabledSites.add(bongaCams.getName());
            }
            save();
        });
        GridPane.setMargin(enabled, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        layout.add(enabled, 1, row++);

        layout.add(new Label("BongaCams User"), 0, row);
        var username = new TextField(settings.bongaUsername);
        username.setPrefWidth(300);
        username.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().bongaUsername)) {
                Config.getInstance().getSettings().bongaUsername = username.getText();
                bongaCams.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(username, true);
        GridPane.setHgrow(username, Priority.ALWAYS);
        GridPane.setColumnSpan(username, 2);
        layout.add(username, 1, row++);

        layout.add(new Label("BongaCams Password"), 0, row);
        var password = new PasswordField();
        password.setText(settings.bongaPassword);
        password.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().bongaPassword)) {
                Config.getInstance().getSettings().bongaPassword = password.getText();
                bongaCams.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(password, true);
        GridPane.setHgrow(password, Priority.ALWAYS);
        GridPane.setColumnSpan(password, 2);
        layout.add(password, 1, row++);

        layout.add(new Label("Bongacams Base URL"), 0, row);
        var baseUrl = new TextField();
        baseUrl.setText(Config.getInstance().getSettings().bongacamsBaseUrl);
        baseUrl.textProperty().addListener((ob, o, n) -> {
            Config.getInstance().getSettings().bongacamsBaseUrl = baseUrl.getText();
            save();
        });
        GridPane.setFillWidth(baseUrl, true);
        GridPane.setHgrow(baseUrl, Priority.ALWAYS);
        GridPane.setColumnSpan(baseUrl, 2);
        layout.add(baseUrl, 1, row++);

        Label tabsLabel = new Label("Tabs");
        layout.add(tabsLabel, 0, row);
        List<String> bcTabs = getBongaTabs();

        HBox checkboxContainer = new HBox(10);

        CheckBox bcFemale = new CheckBox("Female");
        bcFemale.setSelected(bcTabs.contains("female"));
        bcFemale.setOnAction(e -> toggleTabs("female", bcFemale.isSelected()));
        HBox.setMargin(bcFemale, new Insets(0, 0, 0, 7));
        checkboxContainer.getChildren().add(bcFemale);

        CheckBox bcMale = new CheckBox("Male");
        bcMale.setSelected(bcTabs.contains("male"));
        bcMale.setOnAction(e -> toggleTabs("male", bcMale.isSelected()));
        checkboxContainer.getChildren().add(bcMale);

        CheckBox bcCouples = new CheckBox("Couples");
        bcCouples.setSelected(bcTabs.contains("couples"));
        bcCouples.setOnAction(e -> toggleTabs("couples", bcCouples.isSelected()));
        checkboxContainer.getChildren().add(bcCouples);

        CheckBox bcTrans = new CheckBox("Trans");
        bcTrans.setSelected(bcTabs.contains("trans"));
        bcTrans.setOnAction(e -> toggleTabs("trans", bcTrans.isSelected()));
        checkboxContainer.getChildren().add(bcTrans);

        layout.add(checkboxContainer, 1, row, 4, 1);
        row++;

        var createAccount = new Button("Create new Account");
        createAccount.setOnAction(e -> DesktopIntegration.open(bongaCams.getAffiliateLink()));
        layout.add(createAccount, 1, row++);
        GridPane.setColumnSpan(createAccount, 2);

        var deleteCookies = new Button("Delete Cookies");
        deleteCookies.setOnAction(e -> bongaCams.getHttpClient().clearCookies());
        layout.add(deleteCookies, 1, row);
        GridPane.setColumnSpan(deleteCookies, 2);

        GridPane.setMargin(username, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(password, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(baseUrl, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(createAccount, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(deleteCookies, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        return layout;
    }

    private void toggleTabs(String tab, boolean selected) {
        var settings = Config.getInstance().getSettings();
        if (selected) {
            settings.bongaTabs.add(tab);
        } else {
            settings.bongaTabs.remove(tab);
        }
        save();
    }

    private List<String> getBongaTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().bongaTabs);
    }
}
