package ctbrec.ui.sites.bonga;

import ctbrec.Config;
import ctbrec.sites.bonga.BongaCams;
import ctbrec.ui.sites.AbstractTabProvider;
import ctbrec.ui.tabs.PaginatedScheduledService;
import ctbrec.ui.tabs.ThumbOverviewTab;
import javafx.scene.Scene;
import javafx.scene.control.Tab;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class BongaCamsTabProvider extends AbstractTabProvider {

    private String url;
    private PaginatedScheduledService updateService;
    private BongaCamsFriendsTab friendsTab;

    public BongaCamsTabProvider(BongaCams bongaCams) {
        super(bongaCams);
    }

    @Override
    protected List<Tab> getSiteTabs(Scene scene) {
        List<Tab> tabs = new ArrayList<>();

        Map<String, String> tabMap = new HashMap<>();
        tabMap.put("female", "Female");
        tabMap.put("male", "Male");
        tabMap.put("couple", "Couple");
        tabMap.put("trans", "Trans");
        List<String> enabledTabs = getBongaTabs();
        for (String tab : enabledTabs) {
            String url = site.getBaseUrl() + "/tools/listing_v3.php?livetab=" + tab + "&online_only=true&is_mobile=true&limit=72&offset=";
            updateService = new BongaCamsUpdateService((BongaCams) site, url);
            String title = tabMap.getOrDefault(tab, tab);
            tabs.add(createTab(title, updateService));
        }

        // mobile
        url = site.getBaseUrl() + "/tools/listing_v3.php?livetab=all&online_only=true&tag=mobile-live&limit=72&offset=";
        updateService = new BongaCamsUpdateService((BongaCams) site, url);
        tabs.add(createTab("Mobile", updateService));

        // new
        url = site.getBaseUrl() + "/tools/listing_v3.php?livetab=new&online_only=true&is_mobile=true&limit=72&offset=";
        updateService = new BongaCamsUpdateService((BongaCams) site, url);
        tabs.add(createTab("New", updateService));

        // friends
        url = site.getBaseUrl() + "/tools/listing_v3.php?livetab=friends&online_only=true&limit=72&offset=";
        updateService = new BongaCamsUpdateService((BongaCams) site, url, true);
        friendsTab = new BongaCamsFriendsTab("Friends", updateService, site);
        friendsTab.setRecorder(recorder);
        tabs.add(friendsTab);

        return tabs;
    }

    @Override
    public Tab getFollowedTab() {
        return friendsTab;
    }

    private Tab createTab(String title, PaginatedScheduledService updateService) {
        var tab = new ThumbOverviewTab(title, updateService, site);
        tab.setRecorder(recorder);
        return tab;
    }

    private List<String> getBongaTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().bongaTabs);
    }

}
